@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = "1.0.0"
+__version__ = "1.12.1"
 
 from pyobas._version import (  # noqa: F401
     __author__,
@@ -9,8 +9,10 @@ from pyobas._version import (  # noqa: F401
     __title__,
 )
 from pyobas.client import OpenBAS  # noqa: F401
+from pyobas.configuration import *  # noqa: F401,F403,F405
 from pyobas.contracts import *  # noqa: F401,F403,F405
 from pyobas.exceptions import *  # noqa: F401,F403,F405
+from pyobas.signatures import *  # noqa: F401,F403,F405
 
 __all__ = [
     "__author__",
